@@ -1,4 +1,5 @@
-def print_lol(the_list, level):
+level = [0]
+def print_lol(the_list):
 	for each_item in the_list:
 		if isinstance(each_item, list):
 			print_lol(each_item, level+1)
